# Kubextract: ML Kubeflow Framework Generator
Kubextract is a framework generator for end-to-end machine learning development and automate kubeflow job deployment.

### How to use
pip3
  - install pip3 package on your computer
  - export environment variable ```export PATH=$PATH:~/.local/bin```
  - run ```pip3 install kubextract --upgrade```
  - run ```kubextract```
  - input your params.yml location

### Setting pre-commit
- ```pip install pre-commit```
- ```pre-commit install```
- for check previous files, run ```pre-commit run --all-files```

### Documentation
- see config documentation on ```docs/config```
- see architecture decision record on ```docs/adr```
- see example project on ```examples/```
